@@ -48,7 +48,7 @@ enum {
 };
 
 
-static gint image_chooser_signals [LAST_SIGNAL] = { 0 };
+static guint image_chooser_signals [LAST_SIGNAL] = { 0 };
 
 static void e_image_chooser_init	 (EImageChooser		 *chooser);
 static void e_image_chooser_class_init	 (EImageChooserClass	 *klass);
@@ -66,11 +66,7 @@ static void image_drag_data_received_cb (GtkWidget *widget,
 					 GtkSelectionData *selection_data,
 					 guint info, guint time, EImageChooser *chooser);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static GObjectClass *parent_class = NULL;
-#else
-static GtkObjectClass *parent_class = NULL;
-#endif
 #define PARENT_TYPE GTK_TYPE_VBOX
 
 enum DndTargetType {
@@ -281,11 +277,7 @@ image_drag_motion_cb (GtkWidget *widget,
 	if (!chooser->priv->editable)
 		return FALSE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	for (p = gdk_drag_context_list_targets (context); p; p = p->next) {
-#else
-	for (p = context->targets; p != NULL; p = p->next) {
-#endif
 		char *possible_type;
 
 		possible_type = gdk_atom_name (GDK_POINTER_TO_ATOM (p->data));
@@ -311,19 +303,11 @@ image_drag_drop_cb (GtkWidget *widget,
 	if (!chooser->priv->editable)
 		return FALSE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (gdk_drag_context_list_targets (context) == NULL) {
-#else
-	if (context->targets == NULL) {
-#endif
 		return FALSE;
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	for (p = gdk_drag_context_list_targets (context); p; p = p->next) {
-#else
-	for (p = context->targets; p != NULL; p = p->next) {
-#endif
 		char *possible_type;
 
 		possible_type = gdk_atom_name (GDK_POINTER_TO_ATOM (p->data));
