@@ -25,6 +25,7 @@
 #include "appearance-font.h"
 #include "appearance-themes.h"
 #include "appearance-style.h"
+#include "appearance-ui.h"
 #include "appearance-support.h"
 #include "theme-installer.h"
 #include "theme-thumbnail.h"
@@ -72,9 +73,7 @@ init_appearance_data (int *argc, char ***argv, GOptionContext *context)
       data->interface_settings = g_settings_new (INTERFACE_SCHEMA);
       data->marco_settings = g_settings_new (MARCO_SCHEMA);
       data->mouse_settings = g_settings_new (MOUSE_SCHEMA);
-#ifdef HAVE_XFT2
       data->font_settings = g_settings_new (FONT_RENDER_SCHEMA);
-#endif /* HAVE_XFT2 */
       data->ui = ui;
       data->thumb_factory = mate_desktop_thumbnail_factory_new (MATE_DESKTOP_THUMBNAIL_SIZE_NORMAL);
     }
@@ -108,9 +107,7 @@ main_window_response (GtkWidget *widget,
     g_object_unref (data->interface_settings);
     g_object_unref (data->marco_settings);
     g_object_unref (data->mouse_settings);
-#ifdef HAVE_XFT2
     g_object_unref (data->font_settings);
-#endif /* HAVE_XFT2 */
     g_object_unref (data->ui);
   }
   else if (response_id == GTK_RESPONSE_HELP)
@@ -192,6 +189,7 @@ main (int argc, char **argv)
   desktop_init (data, (const gchar **) wallpaper_files);
   g_strfreev (wallpaper_files);
   font_init (data);
+  ui_init (data);
 
   /* init support for other window managers */
   support_init (data);
