@@ -45,6 +45,10 @@
 #define GTK_THEME_KEY                "gtk-theme"
 #define ICON_THEME_KEY               "icon-theme"
 #define COLOR_SCHEME_KEY             "gtk-color-scheme"
+#define ACCEL_CHANGE_KEY             "can-change-accels"
+#define MENU_ICONS_KEY               "menus-have-icons"
+#define TOOLBAR_DETACHABLE_KEY       "toolbar-detachable"
+#define TOOLBAR_STYLE_KEY            "toolbar-style"
 #define GTK_FONT_DEFAULT_VALUE       "Sans 10"
 
 #define LOCKDOWN_SCHEMA              "org.mate.lockdown"
@@ -65,13 +69,11 @@
 #define CURSOR_THEME_KEY             "cursor-theme"
 #define CURSOR_SIZE_KEY              "cursor-size"
 
-#ifdef HAVE_XFT2
 #define FONT_RENDER_SCHEMA           "org.mate.font-rendering"
 #define FONT_ANTIALIASING_KEY        "antialiasing"
 #define FONT_HINTING_KEY             "hinting"
 #define FONT_RGBA_ORDER_KEY          "rgba-order"
 #define FONT_DPI_KEY                 "dpi"
-#endif /* HAVE_XFT2 */
 
 typedef struct {
 	GSettings* settings;
@@ -80,9 +82,7 @@ typedef struct {
 	GSettings* interface_settings;
 	GSettings* marco_settings;
 	GSettings* mouse_settings;
-#ifdef HAVE_XFT2
 	GSettings* font_settings;
-#endif /* HAVE_XFT2 */
 	GtkBuilder* ui;
 	MateDesktopThumbnailFactory* thumb_factory;
 	gulong screen_size_handler;
