@@ -63,6 +63,7 @@ struct App
     GtkWidget	   *panel_checkbox;
     GtkWidget	   *clone_checkbox;
     GtkWidget	   *show_icon_checkbox;
+    GtkWidget      *primary_button;    
 
     /* We store the event timestamp when the Apply button is clicked */
     GtkWidget      *apply_button;
@@ -414,20 +415,6 @@ count_active_outputs (App *app)
     return count;
 }
 
-#if 0
-static int
-count_all_outputs (MateRRConfig *config)
-{
-    int i;
-    MateRROutputInfo **outputs = mate_rr_config_get_outputs (config);
-
-    for (i = 0; outputs[i] != NULL; i++)
-	;
-
-    return i;
-}
-#endif
-
 /* Computes whether "Mirror Screens" (clone mode) is supported based on these criteria:
  *
  * 1. There is an available size for cloning.
@@ -704,6 +691,8 @@ rebuild_gui (App *app)
 #endif
     gtk_widget_set_sensitive (app->panel_checkbox, sensitive);
 
+    gtk_widget_set_sensitive (app->primary_button, app->current_output && !mate_rr_output_info_get_primary(app->current_output));
+
     app->ignore_gui_changes = FALSE;
 }
 
@@ -1667,20 +1656,25 @@ static PangoLayout *
 get_display_name (App *app,
 		  MateRROutputInfo *output)
 {
-    const char *text;
+    char *text;
+    PangoLayout * layout;
 
     if (mate_rr_config_get_clone (app->current_configuration)) {
-	/* Translators:  this is the feature where what you see on your laptop's
-	 * screen is the same as your external monitor.  Here, "Mirror" is being
-	 * used as an adjective, not as a verb.  For example, the Spanish
-	 * translation could be "Pantallas en Espejo", *not* "Espejar Pantallas".
-	 */
-	text = _("Mirror Screens");
-    } else
-	text = mate_rr_output_info_get_display_name (output);
-
-    return gtk_widget_create_pango_layout (
-	GTK_WIDGET (app->area), text);
+    /* Translators:  this is the feature where what you see on your laptop's
+     * screen is the same as your external monitor.  Here, "Mirror" is being
+     * used as an adjective, not as a verb.  For example, the Spanish
+     * translation could be "Pantallas en Espejo", *not* "Espejar Pantallas".
+     */
+        text = g_strdup_printf (_("Mirror Screens"));
+    } 
+    else {
+        text = g_strdup_printf ("<b>%s</b>\n<small>%s</small>", mate_rr_output_info_get_display_name (output), mate_rr_output_info_get_name (output));
+    }
+    layout = gtk_widget_create_pango_layout (GTK_WIDGET (app->area), text);
+    pango_layout_set_markup (layout, text, -1);
+    g_free (text);
+    pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
+    return layout;
 }
 
 static void
@@ -1854,7 +1848,7 @@ paint_output (App *app, cairo_t *cr, int i)
     cairo_stroke (cr);
     cairo_set_line_width (cr, 2);
 
-    layout_set_font (layout, "Sans Bold 12");
+    layout_set_font (layout, "Sans 12");
     pango_layout_get_pixel_extents (layout, &ink_extent, &log_extent);
 
     available_w = w * scale + 0.5 - 6; /* Same as the inner rectangle's width, minus 1 pixel of padding on each side */
@@ -2172,29 +2166,6 @@ apply (App *app)
     begin_version2_apply_configuration (app, gtk_widget_get_window (app->dialog), app->apply_button_clicked_timestamp);
 }
 
-#if 0
-/* Returns whether the graphics driver doesn't advertise RANDR 1.2 features, and just 1.0 */
-static gboolean
-driver_is_randr_10 (MateRRConfig *config)
-{
-    /* In the Xorg code, see xserver/randr/rrinfo.c:RRScanOldConfig().  It gets
-     * called when the graphics driver doesn't support RANDR 1.2 yet, just 1.0.
-     * In that case, the X server's base code (which supports RANDR 1.2) will
-     * simulate having a single output called "default".  For drivers that *do*
-     * support RANDR 1.2, the separate outputs will be named differently, we
-     * hope.
-     *
-     * This heuristic is courtesy of Dirk Mueller <dmueller@suse.de>
-     *
-     * FIXME: however, we don't even check for XRRQueryVersion() returning 1.2, neither
-     * here nor in mate-desktop/libmatedesktop*.c.  Do we need to check for that,
-     * or is mate_rr_screen_new()'s return value sufficient?
-     */
-
-    return (count_all_outputs (config) == 1 && strcmp (mate_rr_output_info_get_name (mate_rr_config_get_outputs (config)[0]), "default") == 0);
-}
-#endif
-
 static void
 on_detect_displays (GtkWidget *widget, gpointer data)
 {
@@ -2210,6 +2181,24 @@ on_detect_displays (GtkWidget *widget, gpointer data)
     }
 }
 
+static void
+set_primary (GtkWidget *widget, gpointer data)
+{
+    App *app = data;
+    int i;
+    MateRROutputInfo **outputs;
+
+    if (!app->current_output)
+        return;
+
+    outputs = mate_rr_config_get_outputs (app->current_configuration);
+    for (i=0; outputs[i]!=NULL; i++) {
+        mate_rr_output_info_set_primary (outputs[i], outputs[i] == app->current_output);
+    }
+
+    gtk_widget_set_sensitive (app->primary_button, !mate_rr_output_info_get_primary(app->current_output));
+}
+
 #define MSD_XRANDR_SCHEMA                 "org.mate.SettingsDaemon.plugins.xrandr"
 #define SHOW_ICON_KEY                     "show-notification-icon"
 #define DEFAULT_CONFIGURATION_FILE_KEY    "default-configuration-file"
@@ -2543,6 +2532,10 @@ run_application (App *app)
     g_signal_connect (_gtk_builder_get_widget (builder, "detect_displays_button"),
 		      "clicked", G_CALLBACK (on_detect_displays), app);
 
+    app->primary_button = _gtk_builder_get_widget (builder, "primary_button");
+
+    g_signal_connect (app->primary_button, "clicked", G_CALLBACK (set_primary), app);
+
     app->show_icon_checkbox = _gtk_builder_get_widget (builder,
 						      "show_notification_icon");
 
