@@ -12,9 +12,6 @@
 #include <X11/Xatom.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
 
 #include "wm-common.h"
 #include "capplet-util.h"
@@ -445,11 +442,7 @@ static gboolean key_match(GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* i
 
     if (element && element->settings && G_IS_SETTINGS(element->settings))
     {
-        #if GLIB_CHECK_VERSION (2, 32, 0)
             g_object_get (element->settings, "schema-id", &element_schema, NULL);
-        #else
-            g_object_get (element->settings, "schema", &element_schema, NULL);
-        #endif
         g_object_get (element->settings, "path", &element_path, NULL);
     }
 
@@ -1112,21 +1105,13 @@ static gboolean cb_check_for_uniqueness(GtkTreeModel* model, GtkTreePath* path,
 
     if (new_key && new_key->settings)
     {
-        #if GLIB_CHECK_VERSION (2, 32, 0)
             g_object_get (new_key->settings, "schema-id", &new_key_schema, NULL);
-        #else
-            g_object_get (new_key->settings, "schema", &new_key_schema, NULL);
-        #endif
         g_object_get (new_key->settings, "path", &new_key_path, NULL);
     }
     
     if (element->settings)
     {
-        #if GLIB_CHECK_VERSION (2, 32, 0)
             g_object_get (element->settings, "schema-id", &element_schema, NULL);
-        #else
-            g_object_get (element->settings, "schema", &element_schema, NULL);
-        #endif
         g_object_get (element->settings, "path", &element_path, NULL);
     }
 
@@ -1161,22 +1146,22 @@ static gboolean cb_check_for_uniqueness(GtkTreeModel* model, GtkTreePath* path,
 
 static const guint forbidden_keyvals[] = {
     /* Navigation keys */
-    GDK_Home,
-    GDK_Left,
-    GDK_Up,
-    GDK_Right,
-    GDK_Down,
-    GDK_Page_Up,
-    GDK_Page_Down,
-    GDK_End,
-    GDK_Tab,
+    GDK_KEY_Home,
+    GDK_KEY_Left,
+    GDK_KEY_Up,
+    GDK_KEY_Right,
+    GDK_KEY_Down,
+    GDK_KEY_Page_Up,
+    GDK_KEY_Page_Down,
+    GDK_KEY_End,
+    GDK_KEY_Tab,
 
     /* Return */
-    GDK_KP_Enter,
-    GDK_Return,
+    GDK_KEY_KP_Enter,
+    GDK_KEY_Return,
 
-    GDK_space,
-    GDK_Mode_switch
+    GDK_KEY_space,
+    GDK_KEY_Mode_switch
 };
 
 static gboolean keyval_is_forbidden(guint keyval)
@@ -1254,17 +1239,17 @@ static void accel_edited_callback(GtkCellRendererText* cell, const char* path_st
     /* Check for unmodified keys */
     if (tmp_key.mask == 0 && tmp_key.keycode != 0)
     {
-        if ((tmp_key.keyval >= GDK_a && tmp_key.keyval <= GDK_z)
-            || (tmp_key.keyval >= GDK_A && tmp_key.keyval <= GDK_Z)
-            || (tmp_key.keyval >= GDK_0 && tmp_key.keyval <= GDK_9)
-            || (tmp_key.keyval >= GDK_kana_fullstop && tmp_key.keyval <= GDK_semivoicedsound)
-            || (tmp_key.keyval >= GDK_Arabic_comma && tmp_key.keyval <= GDK_Arabic_sukun)
-            || (tmp_key.keyval >= GDK_Serbian_dje && tmp_key.keyval <= GDK_Cyrillic_HARDSIGN)
-            || (tmp_key.keyval >= GDK_Greek_ALPHAaccent && tmp_key.keyval <= GDK_Greek_omega)
-            || (tmp_key.keyval >= GDK_hebrew_doublelowline && tmp_key.keyval <= GDK_hebrew_taf)
-            || (tmp_key.keyval >= GDK_Thai_kokai && tmp_key.keyval <= GDK_Thai_lekkao)
-            || (tmp_key.keyval >= GDK_Hangul && tmp_key.keyval <= GDK_Hangul_Special)
-            || (tmp_key.keyval >= GDK_Hangul_Kiyeog && tmp_key.keyval <= GDK_Hangul_J_YeorinHieuh)
+        if ((tmp_key.keyval >= GDK_KEY_a && tmp_key.keyval <= GDK_KEY_z)
+            || (tmp_key.keyval >= GDK_KEY_A && tmp_key.keyval <= GDK_KEY_Z)
+            || (tmp_key.keyval >= GDK_KEY_0 && tmp_key.keyval <= GDK_KEY_9)
+            || (tmp_key.keyval >= GDK_KEY_kana_fullstop && tmp_key.keyval <= GDK_KEY_semivoicedsound)
+            || (tmp_key.keyval >= GDK_KEY_Arabic_comma && tmp_key.keyval <= GDK_KEY_Arabic_sukun)
+            || (tmp_key.keyval >= GDK_KEY_Serbian_dje && tmp_key.keyval <= GDK_KEY_Cyrillic_HARDSIGN)
+            || (tmp_key.keyval >= GDK_KEY_Greek_ALPHAaccent && tmp_key.keyval <= GDK_KEY_Greek_omega)
+            || (tmp_key.keyval >= GDK_KEY_hebrew_doublelowline && tmp_key.keyval <= GDK_KEY_hebrew_taf)
+            || (tmp_key.keyval >= GDK_KEY_Thai_kokai && tmp_key.keyval <= GDK_KEY_Thai_lekkao)
+            || (tmp_key.keyval >= GDK_KEY_Hangul && tmp_key.keyval <= GDK_KEY_Hangul_Special)
+            || (tmp_key.keyval >= GDK_KEY_Hangul_Kiyeog && tmp_key.keyval <= GDK_KEY_Hangul_J_YeorinHieuh)
             || keyval_is_forbidden (tmp_key.keyval))
         {
 
@@ -1902,6 +1887,14 @@ setup_dialog (GtkBuilder *builder, GSettings *marco_settings)
   /* set up the dialog */
   reload_key_entries (builder);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+  widget = _gtk_builder_get_widget (builder, "mate-keybinding-dialog");
+  gtk_window_set_default_size (GTK_WINDOW (widget), 400, 500);
+  widget = _gtk_builder_get_widget (builder, "label-suggest");
+  gtk_label_set_line_wrap (GTK_LABEL (widget), TRUE);
+  gtk_label_set_max_width_chars (GTK_LABEL (widget), 60);
+#endif
+
   widget = _gtk_builder_get_widget (builder, "mate-keybinding-dialog");
   capplet_set_icon (widget, "preferences-desktop-keyboard-shortcuts");
   gtk_widget_show (widget);
@@ -1939,9 +1932,6 @@ main (int argc, char *argv[])
   GtkBuilder *builder;
   GSettings *marco_settings;
 
-#if !GLIB_CHECK_VERSION (2, 32, 0)
-  g_thread_init (NULL);
-#endif
   gtk_init (&argc, &argv);
 
   bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
