@@ -419,7 +419,7 @@ chooser_response_cb (GtkDialog * dialog, gint response, gpointer data)
 	switch (response) {
 	case GTK_RESPONSE_HELP:
 		capplet_help (GTK_WINDOW (dialog),
-			      "prefs-keyboard-layoutoptions");
+			      "prefs-keyboard#prefs-keyboard-layoutoptions");
 		break;
 	case GTK_RESPONSE_CLOSE:{
 			/* just cleanup */
