@@ -34,7 +34,6 @@
 #include "capplet-util.h"
 #include "activate-settings-daemon.h"
 #include "capplet-stock-icons.h"
-//#include "mate-mouse-accessibility.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -48,10 +47,6 @@
 #include <X11/Xcursor/Xcursor.h>
 #endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define GtkFunction GSourceFunc
-#endif
-
 enum
 {
 	DOUBLE_CLICK_TEST_OFF,
@@ -141,24 +136,28 @@ event_box_button_press_event (GtkWidget   *widget,
 
 	double_click_time = g_settings_get_int (mouse_settings, DOUBLE_CLICK_KEY);
 
-	if (test_maybe_timeout_id != 0)
+	if (test_maybe_timeout_id != 0) {
 		g_source_remove  (test_maybe_timeout_id);
-	if (test_on_timeout_id != 0)
+		test_maybe_timeout_id = 0;
+	}
+	if (test_on_timeout_id != 0) {
 		g_source_remove (test_on_timeout_id);
+		test_on_timeout_id = 0;
+	}
 
 	switch (double_click_state) {
 	case DOUBLE_CLICK_TEST_OFF:
 		double_click_state = DOUBLE_CLICK_TEST_MAYBE;
 		data.image = image;
 		data.timeout_id = &test_maybe_timeout_id;
-		test_maybe_timeout_id = g_timeout_add (double_click_time, (GtkFunction) test_maybe_timeout, &data);
+		test_maybe_timeout_id = g_timeout_add (double_click_time, (GSourceFunc) test_maybe_timeout, &data);
 		break;
 	case DOUBLE_CLICK_TEST_MAYBE:
 		if (event->time - double_click_timestamp < double_click_time) {
 			double_click_state = DOUBLE_CLICK_TEST_ON;
 			data.image = image;
 			data.timeout_id = &test_on_timeout_id;
-			test_on_timeout_id = g_timeout_add (2500, (GtkFunction) test_maybe_timeout, &data);
+			test_on_timeout_id = g_timeout_add (2500, (GSourceFunc) test_maybe_timeout, &data);
 		}
 		break;
 	case DOUBLE_CLICK_TEST_ON:
@@ -216,6 +215,8 @@ scrollmethod_gsettings_changed_event (GSettings *settings,
 				scroll_method == 2);
 	gtk_widget_set_sensitive (WID ("horiz_scroll_toggle"),
 				 scroll_method != 0);
+	gtk_widget_set_sensitive (WID ("natural_scroll_toggle"),
+				 scroll_method != 0);
 }
 
 static void
@@ -227,6 +228,9 @@ scrollmethod_clicked_event (GtkWidget *widget,
 	gtk_widget_set_sensitive (WID ("horiz_scroll_toggle"),
 				  !gtk_toggle_button_get_active (disabled));
 
+	gtk_widget_set_sensitive (WID ("natural_scroll_toggle"),
+				  !gtk_toggle_button_get_active (disabled));
+
 	GSList *radio_group;
 	int new_scroll_method;
 	int old_scroll_method = g_settings_get_int (touchpad_settings, "scroll-method");
@@ -351,6 +355,14 @@ find_synaptics (void)
 	return ret;
 }
 
+static void
+comboxbox_changed_callback (GtkWidget *combobox, void *data)
+{
+    gint value = gtk_combo_box_get_active (GTK_COMBO_BOX (combobox));
+    gchar *key = (char *) data;
+    g_settings_set_int (touchpad_settings, key, value);
+}
+
 /* Set up the property editors in the dialog. */
 static void
 setup_dialog (GtkBuilder *dialog)
@@ -400,6 +412,15 @@ setup_dialog (GtkBuilder *dialog)
 	if (find_synaptics () == FALSE)
 		gtk_notebook_remove_page (GTK_NOTEBOOK (WID ("prefs_widget")), -1);
 	else {
+		g_settings_bind (touchpad_settings, "touchpad-enabled",
+			WID ("touchpad_enable"), "active",
+			G_SETTINGS_BIND_DEFAULT);
+		g_settings_bind (touchpad_settings, "touchpad-enabled",
+			WID ("vbox_touchpad_general"), "sensitive",
+			G_SETTINGS_BIND_DEFAULT);
+		g_settings_bind (touchpad_settings, "touchpad-enabled",
+			WID ("vbox_touchpad_scrolling"), "sensitive",
+			G_SETTINGS_BIND_DEFAULT);
 		g_settings_bind (touchpad_settings, "disable-while-typing",
 			WID ("disable_w_typing_toggle"), "active",
 			G_SETTINGS_BIND_DEFAULT);
@@ -409,9 +430,31 @@ setup_dialog (GtkBuilder *dialog)
 		g_settings_bind (touchpad_settings, "horiz-scroll-enabled",
 			WID ("horiz_scroll_toggle"), "active",
 			G_SETTINGS_BIND_DEFAULT);
+		g_settings_bind (touchpad_settings, "natural-scroll",
+			WID ("natural_scroll_toggle"), "active",
+			G_SETTINGS_BIND_DEFAULT);
 
 		scrollmethod_gsettings_changed_event (touchpad_settings, "scroll-method", dialog);
 
+		char * emulation_values[] = { _("Disabled"), _("Left button"), _("Middle button"), _("Right button") };
+
+		GtkWidget *two_click_comboxbox = gtk_combo_box_text_new ();
+		GtkWidget *three_click_comboxbox = gtk_combo_box_text_new ();
+		gtk_box_pack_start (GTK_BOX (WID ("hbox_two_finger_click")), two_click_comboxbox, FALSE, FALSE, 6);
+		gtk_box_pack_start (GTK_BOX (WID ("hbox_three_finger_click")), three_click_comboxbox, FALSE, FALSE, 6);
+		int i;
+		for (i=0; i<4; i++) {
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (two_click_comboxbox), emulation_values[i]);	
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (three_click_comboxbox), emulation_values[i]);	
+		}
+		
+		gtk_combo_box_set_active (GTK_COMBO_BOX (two_click_comboxbox), g_settings_get_int (touchpad_settings, "two-finger-click"));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (three_click_comboxbox), g_settings_get_int (touchpad_settings, "three-finger-click"));
+		gtk_widget_show (two_click_comboxbox);
+		gtk_widget_show (three_click_comboxbox);
+		g_signal_connect (two_click_comboxbox, "changed", G_CALLBACK (comboxbox_changed_callback), "two-finger-click");
+		g_signal_connect (three_click_comboxbox, "changed", G_CALLBACK (comboxbox_changed_callback), "three-finger-click");
+
 		radio = GTK_RADIO_BUTTON (WID ("scroll_disabled_radio"));
 		GSList *radio_group = gtk_radio_button_get_group (radio);
 		GSList *item = NULL;
@@ -512,7 +555,6 @@ main (int argc, char **argv)
 
 	if (dialog) {
 		setup_dialog (dialog);
-		//setup_accessibility (dialog);
 
 		dialog_win = WID ("mouse_properties_dialog");
 		g_signal_connect (dialog_win, "response",
