@@ -22,7 +22,7 @@
 #define __MATE_UTILS_H__
 
 #include <gtk/gtk.h>
-#include <libmate/mate-desktop-item.h>
+#include <libmate-desktop/mate-desktop-item.h>
 
 #ifdef __cplusplus
 extern "C" {
