@@ -25,7 +25,7 @@
 #include <gtk/gtk.h>
 #include <libmate-desktop/mate-desktop-item.h>
 
-#include <libslab/app-shell.h>
+#include "app-shell.h"
 
 #ifdef __cplusplus
 extern "C" {
