@@ -21,7 +21,7 @@
 #ifndef __SYSTEM_TILE_H__
 #define __SYSTEM_TILE_H__
 
-#include <libslab/nameplate-tile.h>
+#include "nameplate-tile.h"
 
 #include <libmate-desktop/mate-desktop-item.h>
 
